Stan Math Library: stan/math/rev/core/operator_less_than_or_equal.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_less_than_or_equal.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_OPERATOR_LESS_THAN_OR_EQUAL_HPP
2 #define STAN_MATH_REV_CORE_OPERATOR_LESS_THAN_OR_EQUAL_HPP
3
4 #include <stan/math/rev/core/var.hpp>
5
6 namespace stan {
7 namespace math {
8
26 inline bool operator<=(const var& a, const var& b) {
27 return a.val() <= b.val();
28 }
29
39 inline bool operator<=(const var& a, const double b) {
40 return a.val() <= b;
41 }
42
52 inline bool operator<=(const double a, const var& b) {
53 return a <= b.val();
54 }
55
56 }
57 }
58 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::operator<=
bool operator<=(const fvar< T > &x, const fvar< T > &y)
Definition: operator_less_than_or_equal.hpp:14
var.hpp
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233

[ Stan Home Page ] © 2011–2016, Stan Development Team.